@@ -36,13 +36,13 @@ class UnexpectedRuleException(CfnLintExitException):
     """When processing a rule fails in an unexpected way"""
 
 
-def run_cli(filename, template, rules, regions, override_spec):
+def run_cli(filename, template, rules, regions, override_spec, mandatory_rules=None):
     """Process args and run"""
 
     if override_spec:
         cfnlint.helpers.override_specs(override_spec)
 
-    return run_checks(filename, template, rules, regions)
+    return run_checks(filename, template, rules, regions, mandatory_rules)
 
 
 def get_exit_code(matches):
@@ -76,14 +76,17 @@ def get_formatter(fmt):
     return formatter
 
 
-def get_rules(rulesdir, ignore_rules, include_rules, configure_rules=None, include_experimental=False):
+def get_rules(append_rules, ignore_rules, include_rules, configure_rules=None, include_experimental=False, mandatory_rules=None):
     """Get rules"""
-    rules = RulesCollection(ignore_rules, include_rules, configure_rules, include_experimental)
-    rules_dirs = [DEFAULT_RULESDIR] + rulesdir
+    rules = RulesCollection(ignore_rules, include_rules, configure_rules, include_experimental, mandatory_rules)
+    rules_paths = [DEFAULT_RULESDIR] + append_rules
     try:
-        for rules_dir in rules_dirs:
-            rules.create_from_directory(rules_dir)
-    except OSError as e:
+        for rules_path in rules_paths:
+            if rules_path and os.path.isdir(os.path.expanduser(rules_path)):
+                rules.create_from_directory(rules_path)
+            else:
+                rules.create_from_module(rules_path)
+    except (OSError, ImportError) as e:
         raise UnexpectedRuleException('Tried to append rules but got an error: %s' % str(e), 1)
     return rules
 
@@ -111,7 +114,7 @@ def get_args_filenames(cli_args):
 
     if config.update_documentation:
         # Get ALL rules (ignore the CLI settings))
-        documentation_rules = cfnlint.core.get_rules([], [], ['I', 'E', 'W'], {}, True)
+        documentation_rules = cfnlint.core.get_rules([], [], ['I', 'E', 'W'], {}, True, [])
         cfnlint.maintenance.update_documentation(documentation_rules)
         sys.exit(0)
 
@@ -124,7 +127,8 @@ def get_args_filenames(cli_args):
             config.append_rules,
             config.ignore_checks,
             config.include_checks,
-            config.configure_rules
+            config.configure_rules,
+            config.mandatory_checks,
         )
         print(rules)
         sys.exit(0)
@@ -156,12 +160,13 @@ def get_template_rules(filename, args):
         args.include_checks,
         args.configure_rules,
         args.include_experimental,
+        args.mandatory_checks,
     )
 
     return(template, rules, [])
 
 
-def run_checks(filename, template, rules, regions):
+def run_checks(filename, template, rules, regions, mandatory_rules=None):
     """Run Checks against the template"""
     if regions:
         if not set(regions).issubset(set(REGIONS)):
@@ -172,7 +177,7 @@ def run_checks(filename, template, rules, regions):
 
     matches = []
 
-    runner = cfnlint.Runner(rules, filename, template, regions)
+    runner = cfnlint.Runner(rules, filename, template, regions, mandatory_rules=mandatory_rules)
     matches.extend(runner.transform())
     # Only do rule analysis if Transform was successful
     if not matches:
