@@ -1,23 +1,12 @@
 """
-  Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
-
-  Permission is hereby granted, free of charge, to any person obtaining a copy of this
-  software and associated documentation files (the "Software"), to deal in the Software
-  without restriction, including without limitation the rights to use, copy, modify,
-  merge, publish, distribute, sublicense, and/or sell copies of the Software, and to
-  permit persons to whom the Software is furnished to do so.
-
-  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
-  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
-  PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT
-  HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
-  OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE
-  SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
+Copyright 2019 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+SPDX-License-Identifier: MIT-0
 """
 import six
 import cfnlint.helpers
 from cfnlint.rules import CloudFormationLintRule
 from cfnlint.rules import RuleMatch
+from cfnlint.data import AdditionalSpecs
 
 
 class InstanceSize(CloudFormationLintRule):
@@ -29,7 +18,7 @@ class InstanceSize(CloudFormationLintRule):
     source_url = 'https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/Concepts.DBInstanceClass.html'
     tags = ['resources', 'rds']
 
-    valid_instance_types = cfnlint.helpers.load_resources('data/AdditionalSpecs/RdsProperties.json')
+    valid_instance_types = cfnlint.helpers.load_resource(AdditionalSpecs, 'RdsProperties.json')
 
     def _get_license_model(self, engine, license_model):
         """ Logic to get the correct license model"""
@@ -40,7 +29,8 @@ class InstanceSize(CloudFormationLintRule):
                 license_model = 'bring-your-own-license'
             else:
                 license_model = 'general-public-license'
-            self.logger.debug('Based on Engine: %s we determined the default license will be %s', engine, license_model)
+            self.logger.debug(
+                'Based on Engine: %s we determined the default license will be %s', engine, license_model)
 
         return license_model
 
@@ -70,9 +60,11 @@ class InstanceSize(CloudFormationLintRule):
                                 'LicenseModel': license_model
                             })
                     else:
-                        self.logger.debug('Skip evaluation based on [LicenseModel] not being a string.')
+                        self.logger.debug(
+                            'Skip evaluation based on [LicenseModel] not being a string.')
                 else:
-                    self.logger.debug('Skip evaluation based on [Engine] or [DBInstanceClass] not being strings.')
+                    self.logger.debug(
+                        'Skip evaluation based on [Engine] or [DBInstanceClass] not being strings.')
 
         return results
 
